#SOLUTIONS FOR POLYNOMIAL EQUATIONS

#### This package is used to find the solutions for polynomial equations

## Installation
Run the following code to install this package:
    '''cmd pip install polynomialmathsolution_pms'''

##Contributor: Anitha K
##Mentor: Venkateshwar